.. _debops_api:

DebOps API
==========

.. toctree::
   :maxdepth: 2

   introduction
   getting-started
   api-reference-v0

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
